# GC content and CpG % plots 

library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(dplyr)


promoter <- fread("dunnart_promoters_homerAnnot.txt")
enhancer <- fread("dunnart_enhancers_homerAnnot.txt")
peaks = list(promoter, enhancer)
peaks = Map(mutate,peaks,cre=c("promoters", "enhancers"))
peaks = lapply(peaks, function(x) x %>% dplyr::select("Chr", "Start", "End", "Peak Score", "Distance to TSS", "CpG%", "GC%", "cre") %>% as.data.table())
peaks = rbindlist(peaks)
colnames(peaks)[5:7] <- c("distanceToTSS","CpG", "GC")
peaks[is.na(peaks)] <- 0
peaks = peaks[,log10_abs_dist:=log10(abs(distanceToTSS)+1)]
promoter = subset(peaks, cre == "promoters")
enhancer = subset(peaks, cre == "enhancers")
promoter.subset=subset(promoter, log10_abs_dist >= 3.5)
promoter.subset2 = subset(promoter, log10_abs_dist <3.5)
promoter.subset$cre = "subset>3.5"
promoter.subset2$cre = "subset<3.5"
data = rbind(enhancer, promoter, promoter.subset2, promoter.subset)

p <- ggplot(data, aes(factor(cre), y = GC)) + 
  #geom_violin(aes(fill=factor(cre), color=factor(cre)),
  #  position = "dodge"
  #  )+
  geom_boxplot(aes(color=factor(cre)),
    #outlier.shape = NA,
    width = .2, 
    notch = TRUE,
    fill=c("#FCF8EC","#E4F3F1", "#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  ) + theme_bw() + xlab("") + ylab("CpG %") 
pdf("GC.pdf", width=9, height = 8)
p +  scale_color_manual(values = c("#E9C46A","#2A9D8F","#E9C46A","#2A9D8F")) +
scale_fill_manual(values = c("#F1DAA2","#7AC2B9","#E9C46A","#2A9D8F"))
dev.off()

pairwise.wilcox.test(data$GC, data$cre, p.adjust.method="fdr")

p <- ggplot(peaks, aes(factor(cre), y = GC.width)) + 
  geom_violin(aes(fill=factor(cre), color=factor(cre)),
    position = "dodge"
    )+
  geom_boxplot(aes(color=factor(cre)),
    outlier.shape = NA,
    width = .15, 
    notch = TRUE,
    fill=c("#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  ) + theme_bw() + xlab("") + ylab("GC content %") 
pdf("GC.width_plot.pdf", width=9, height = 8)
p +  scale_color_manual(values = c("#E9C46A","#2A9D8F")) +
scale_fill_manual(values = c("#F1DAA2","#7AC2B9")) + stat_compare_means(method = "wilcox.test" )
dev.off()