library(GenomicFeatures)
library(GenomicRanges)
library(rtracklayer)
library(AnnotationForge)
library(clusterProfiler)
library(ChIPseeker)
library(ggpubr)
library(AnnotationDbi)
library(AnnotationHub)
library(org.Mm.eg.db)
library(plyr)
library(ChIPpeakAnno)
library(tidyverse)
library(RColorBrewer)
library(ggplot2)

## Make txdb for dunnart annotation file
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2")
smiCra_txdb <- makeTxDbFromGFF("Scras_dunnart_assem1.0_pb-ont-illsr_flyeassem_red-rd-scfitr2_pil2xwgs2_60chr2.gff")


## geneID conversion tables
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
df2 <- read.table("biomart_ensembl.txt", header=TRUE, sep="\t") ## conversion table for devil ENSEMBL to mouse ENSEMBL
df3 <- read.table("bioDBnet_refseq2ensembl_H3K27ac.txt", header=TRUE, sep="\t") ## convertsion table for devil refseq to devil ENSEMBL

#################################################### DUNNART ANNOTATION ##########################################################
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2")

## Anotate peak files
annotatePeaks <- function(peak, outFile, outFile1, annoBar, distanceTSS, heatmapTSS, GOenrich, kegg){
  
  # Annotate peak file based on dunnart GFF
  peakAnno <- annotatePeak(peak, tssRegion = c(-3000, 3000), TxDb = smiCra_txdb)
  
  #Plot annotation
  # pdf(file=annoBar, width=10, height=7)
  # print(plotAnnoBar(peakAnno))
  # dev.off()
  
  # Set promoter range
  # promoter <- getPromoters(TxDb=smiCra_txdb, upstream=3000, downstream=3000)
  
  # # Find distance from TSS
  # tagMatrix <- getTagMatrix(toGRanges(peak), windows=promoter)
  
  # # Plot heatmap on peak distance to TSS
  # pdf(file=heatmapTSS, width=10, height=7)
  # print(tagHeatmap(tagMatrix, xlim=c(-3000, 3000), color = "#6699CC"))
  # dev.off()

  # Plot distance from TSS
  # pdf(file=distanceTSS, width=10, height=7)
  # print(plotAvgProf(tagMatrix, xlim=c(-300000, 300000)))
  # dev.off()

  # Write annotation to file
  write.table(peakAnno, outFile, sep="\t", quote=F, row.names=F)
  
  peakAnnoDF <- as.data.frame(peakAnno, row.names = NULL)
  # # Convert refseq IDs and geneIDs to devil ensembl IDs
  peakAnnoDF$ensemblgeneID <- df2$Gene.stable.ID[match(unlist(peakAnnoDF$geneId), df2$Gene.name)]
  peakAnnoDF$ensemblgeneID = replace(peakAnnoDF$ensemblgeneID,is.na(refseqID),"-")
  peakAnnoDF$transcriptIdAltered <- gsub("\\..*","", peakAnnoDF$transcriptId)
  peakAnnoDF$refseqID <- df3$Ensembl.Gene.ID[match(unlist(peakAnnoDF$transcriptIdAltered), df3$RefSeq.mRNA.Accession)]
  peakAnnoDF$refseqID = replace(refseqID$ensemblgeneID,is.na(refseqID),"-")
  peakAnnoDF$combined <- ifelse(peakAnnoDF$refseqID == "-", peakAnnoDF$ensemblgeneID, peakAnnoDF$refseqID)
  peakAnnoDF$refseqID[peakAnnoDF$refseqID == as.character("-")] <- NA
  
  # # Convert devil ensembl to mouse ensembl
  peakAnnoDF$mouseensembl <- df2$Mouse.gene.stable.ID[match(unlist(peakAnnoDF$combined), df2$Gene.stable.ID)]
  # # Write annotation with converted IDs 
  peakAnnoDF <- peakAnnoDF[!is.na(peakAnnoDF$mouseensembl),]
  write.table(peakAnnoDF, outFile1, sep="\t", quote=F, row.names=F)

  # # GO enrichment analysis
  GO <- enrichGO(gene = peakAnnoDF$mouseensembl,
                  keyType = "ENSEMBL",
                  OrgDb = org.Mm.eg.db,
                  ont = "BP",
                  pAdjustMethod = "BH",
                  qvalueCutoff = 0.05,
                  readable = TRUE)
   write.table(GO, GOenrich, sep="\t", quote=F, row.names=F)
  
  # ## convert mouse ensembl to entrezID
  suppressWarnings(gene.df <- bitr(geneID=peakAnnoDF$mouseensembl, fromType="ENSEMBL", toType="ENTREZID", OrgDb="org.Mm.eg.db" ))
  
  # ## kegg analysis
  kk <- enrichKEGG(gene = gene.df$ENTREZID, organism = "mmu", pvalueCutoff=0.05)
  write.table(kk, kegg, sep="\t", quote=F, row.names=F)
}


### Consensus peaks
annotatePeaks(peak = "dunnart_enhancers.narrowPeak", outFile = "dunnart_enhancer_annotation.txt", annoBar = "dunnart_enhancer_annoBar.pdf", distanceTSS = "dunnart_enhancer_distanceTSS.pdf", heatmapTSS = "dunnart_enhancer_heatmapTSS.pdf", outFile1 = "dunnart_enhancer_annotationConvertedIDs.txt", GOenrich = "enhancer_mm10GOenrich.txt", kegg="enhancer_KEGG.txt")
annotatePeaks(peak = "dunnart_promoters.narrowPeak", outFile = "dunnart_promoter_annotation.txt", annoBar = "dunnart_promoter_annoBar.pdf", distanceTSS = "dunnart_promoter_distanceTSS.pdf", heatmapTSS = "dunnart_promoter_heatmapTSS.pdf", outFile1 = "dunnart_promoter_annotationConvertedIDs.txt" , GOenrich = "promoter_mm10GOenrich.txt", kegg="promoter_KEGG.txt")
annotatePeaks(peak = "cluster1_promoters.narrowPeak", outFile = "cluster1_promoter_annotation.txt", annoBar = "cluster1_promoter_annoBar.pdf", distanceTSS = "cluster1_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_promoter_heatmapTSS.pdf", outFile1 = "cluster1_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster1_mm10GOenrich.txt", kegg="cluster1_KEGG.txt")
annotatePeaks(peak = "cluster2_promoters.narrowPeak", outFile = "cluster2_promoter_annotation.txt", annoBar = "cluster2_promoter_annoBar.pdf", distanceTSS = "cluster2_promoter_distanceTSS.pdf", heatmapTSS = "cluster2_promoter_heatmapTSS.pdf", outFile1 = "cluster2_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster2_mm10GOenrich.txt", kegg="cluster2_KEGG.txt")
annotatePeaks(peak = "cluster3_promoters.narrowPeak", outFile = "cluster3_promoter_annotation.txt", annoBar = "cluster3_promoter_annoBar.pdf", distanceTSS = "cluster3_promoter_distanceTSS.pdf", heatmapTSS = "cluster3_promoter_heatmapTSS.pdf", outFile1 = "cluster3_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster3_mm10GOenrich.txt", kegg="cluster3_KEGG.txt")

annotatePeaks(peak = "H3K4me3_overlap.narrowPeak", outFile = "H3K4me3_annotation.txt", annoBar = "H3K4me3_overlap_annoBar.pdf", distanceTSS = "H3K4me3_overlap_distanceTSS.pdf", heatmapTSS = "H3K4me3_overlap_heatmapTSS.pdf", outFile1 = "H3K4me3_overlap_annotationConvertedIDs.txt", GOenrich = "H3K4me3_overlap_mm10GOenrich", kegg="H3K4me3_overlap_KEGG.txt")
annotatePeaks(peak = "H3K27ac_overlap.narrowPeak", outFile = "H3K27ac_annotation.txt", annoBar = "H3K27ac_overlap_annoBar.pdf", distanceTSS = "H3K27ac_overlap_distanceTSS.pdf", heatmapTSS = "H3K27ac_overlap_heatmapTSS.pdf", outFile1 = "H3K27ac_overlap_annotationConvertedIDs.txt" , GOenrich = "H3K27ac_overlap_mm10GOenrich", kegg="H3K27ac_overlap_KEGG.txt")

annotatePeaks(peak = "H3K4me3_and_H3K27ac.narrowPeak", outFile = "H3K4me3_and_H3K27ac_annotation.txt")
annotatePeaks(peak = "H3K4me3_only.narrowPeak", outFile = "H3K4me3_only_annotation.txt")
annotatePeaks(peak = "H3K27ac_only.narrowPeak", outFile = "H3K27ac_only_annotation.txt")