## Input: ChIP-seq peak files
## Output: Various QC plots looking at number of peaks, length, peak intensity etc.

library(ChIPpeakAnno)
library(data.table)
library(ggplot2)

###################################################################################################
############################## QUALITY CONTROL ON PEAKS ###########################################
###################################################################################################

## Number of overlapping peaks for histone marks
peak1 <- toGRanges("H3K27ac_overlap.narrowPeak")
peak2 <- toGRanges("H3K4me3_overlap.narrowPeak")
makeVennDiagram(list(peak1, peak2), NameOfPeaks=c("H3K27ac", "H3K4me3"), 
                maxgap=-1L, minoverlap=0L,
                totalTest=150000,scaled=FALSE, euler.d=FALSE, 
                fill=c("#6699CC", "#CC6677")) # circle fill color

setwd("/Users/lauracook/OneDrive - The University of Melbourne/PhD (2018-2021)/6-ChIPseq/3-DataAnalysis/5-mousePeaks/2-Subsample10Mreads/")

pk1<- toGRanges("H3K4me3_E10.5_overlap.narrowPeak")
pk2<- toGRanges("H3K4me3_E11.5_overlap.narrowPeak")
pk3<- toGRanges("H3K4me3_E12.5_overlap.narrowPeak")
pk4<- toGRanges("H3K4me3_E13.5_overlap.narrowPeak")
pk5<- toGRanges("H3K4me3_E14.5_overlap.narrowPeak")
pk6<- toGRanges("H3K4me3_E15.5_overlap.narrowPeak")
makeVennDiagram(list(pk6,pk12), NameOfPeaks=c("H3K4me3", "H3K27ac"), 
                maxgap=-1L, minoverlap=0L,
                totalTest=150000,scaled=FALSE, euler.d=FALSE,
                fill=c("#6699CC", "#CC6677"))

pk7<- toGRanges("H3K27ac_E10.5_overlap.narrowPeak")
pk8<- toGRanges("H3K27ac_E11.5_overlap.narrowPeak")
pk9<- toGRanges("H3K27ac_E12.5_overlap.narrowPeak")
pk10<- toGRanges("H3K27ac_E13.5_overlap.narrowPeak")
pk11<- toGRanges("H3K27ac_E14.5_overlap.narrowPeak")
pk12<- toGRanges("H3K27ac_E15.5_overlap.narrowPeak")


setwd("/Users/lauracook/OneDrive - The University of Melbourne/PhD (2018-2021)/6-ChIPseq/3-DataAnalysis/2-CrossSpecies/4-Peaks/2-DunnartSubsample10Mreads/")
dH3K4me3 <- read.table("H3K4me3_overlap.narrowPeak", header=FALSE)
dH3K27ac <- read.table("H3K27ac_overlap.narrowPeak", header=FALSE)
denhancer <- read.table("dunnart_enhancer_peaks.narrowPeak", header=FALSE)
dpromoter <- read.table("dunnart_promoter_peaks.narrowPeak", header=FALSE)

setwd("/Users/lauracook/OneDrive - The University of Melbourne/PhD (2018-2021)/6-ChIPseq/3-DataAnalysis/2-CrossSpecies/4-Peaks/1-MouseSubsample10Mreads/")

mH3K4E10 <- read.table("H3K4me3_E10.5_overlap.narrowPeak", header=FALSE)
mH3K4E11 <- read.table("H3K4me3_E11.5_overlap.narrowPeak", header=FALSE)
mH3K4E12 <- read.table("H3K4me3_E12.5_overlap.narrowPeak", header=FALSE)
mH3K4E13 <- read.table("H3K4me3_E13.5_overlap.narrowPeak", header=FALSE)
mH3K4E14 <- read.table("H3K4me3_E14.5_overlap.narrowPeak", header=FALSE)
mH3K4E15 <- read.table("H3K4me3_E15.5_overlap.narrowPeak", header=FALSE)

mH3K27E10 <- read.table("H3K27ac_E10.5_overlap.narrowPeak", header=FALSE)
mH3K27E11 <- read.table("H3K27ac_E11.5_overlap.narrowPeak", header=FALSE)
mH3K27E12 <- read.table("H3K27ac_E12.5_overlap.narrowPeak", header=FALSE)
mH3K27E13 <- read.table("H3K27ac_E13.5_overlap.narrowPeak", header=FALSE)
mH3K27E14 <- read.table("H3K27ac_E14.5_overlap.narrowPeak", header=FALSE)
mH3K27E15 <- read.table("H3K27ac_E15.5_overlap.narrowPeak", header=FALSE)

enhancer10 <- read.table("E10.5_enhancer_peaks.narrowPeak", header=FALSE)
enhancer11 <- read.table("E11.5_enhancer_peaks.narrowPeak", header=FALSE)
enhancer12 <- read.table("E12.5_enhancer_peaks.narrowPeak", header=FALSE)
enhancer13 <- read.table("E13.5_enhancer_peaks.narrowPeak", header=FALSE)
enhancer14 <- read.table("E14.5_enhancer_peaks.narrowPeak", header=FALSE)
enhancer15 <- read.table("E15.5_enhancer_peaks.narrowPeak", header=FALSE)

promoter10 <- read.table("E10.5_promoter_peaks.narrowPeak", header=FALSE)
promoter11 <- read.table("E11.5_promoter_peaks.narrowPeak", header=FALSE)
promoter12 <- read.table("E12.5_promoter_peaks.narrowPeak", header=FALSE)
promoter13 <- read.table("E13.5_promoter_peaks.narrowPeak", header=FALSE)
promoter14 <- read.table("E14.5_promoter_peaks.narrowPeak", header=FALSE)
promoter15 <- read.table("E15.5_promoter_peaks.narrowPeak", header=FALSE)


denhancer$sample <- "enhancer P0"
dpromoter$sample <- "promoter P0"

enhancer10$sample <- "enhancer E10.5"
enhancer11$sample <- "enhancer E11.5"
enhancer12$sample <- "enhancer E12.5"
enhancer13$sample <- "enhancer E13.5"
enhancer14$sample <- "enhancer E14.5"
enhancer15$sample <- "enhancer E15.5"

promoter10$sample <- "promoter E10.5"
promoter11$sample <- "promoter E11.5"
promoter12$sample <- "promoter E12.5"
promoter13$sample <- "promoter E13.5"
promoter14$sample <- "promoter E14.5"
promoter15$sample <- "promoter E15.5"

enhancer10$species <- "mouse"
enhancer11$species <- "mouse"
enhancer12$species <- "mouse"
enhancer13$species <- "mouse"
enhancer14$species <- "mouse"
enhancer15$species <- "mouse"

promoter10$species <- "mouse"
promoter11$species <- "mouse"
promoter12$species <- "mouse"
promoter13$species <- "mouse"
promoter14$species <- "mouse"
promoter15$species <- "mouse"

denhancer$species <- "dunnart"
dpromoter$species <- "dunnart"

enh_prom <- rbind(denhancer, dpromoter, enhancer10, enhancer11, enhancer12, enhancer13, enhancer14, enhancer15, promoter10, promoter11, promoter12, promoter13, promoter14, promoter15 )

dH3K4me3$sample <- "H3K4me3 P0"
dH3K27ac$sample <- "H3K27ac P0"
dH3K4me3$species <- "dunnart"
dH3K27ac$species <- "dunnart"


mH3K4E10$species <- "mouse"
mH3K4E11$species <- "mouse"
mH3K4E12$species <- "mouse"
mH3K4E13$species <- "mouse"
mH3K4E14$species <- "mouse"
mH3K4E15$species <- "mouse"

mH3K4E10$sample <- "H3K4me3 E10.5"
mH3K4E11$sample <- "H3K4me3 E11.5"
mH3K4E12$sample <- "H3K4me3 E12.5"
mH3K4E13$sample <- "H3K4me3 E13.5"
mH3K4E14$sample <- "H3K4me3 E14.5"
mH3K4E15$sample <- "H3K4me3 E15.5"

mH3K27E10$species <- "mouse"
mH3K27E11$species <- "mouse"
mH3K27E12$species <- "mouse"
mH3K27E13$species <- "mouse"
mH3K27E14$species <- "mouse"
mH3K27E15$species <- "mouse"

mH3K27E10$sample <- "H3K27ac E10.5"
mH3K27E11$sample <- "H3K27ac E11.5"
mH3K27E12$sample <- "H3K27ac E12.5"
mH3K27E13$sample <- "H3K27ac E13.5"
mH3K27E14$sample <- "H3K27ac E14.5"
mH3K27E15$sample <- "H3K27ac E15.5"

fullPeaks <- rbind(dH3K4me3, dH3K27ac, mH3K27E10, mH3K27E11, mH3K27E12, mH3K27E13, mH3K27E14, mH3K27E15, mH3K4E10, mH3K4E11, mH3K4E12, mH3K4E13, mH3K4E14, mH3K4E15)

# Number of peaks per gene for enhancers and promoters
setwd("/Users/lauracook/OneDrive - The University of Melbourne/PhD (2018-2021)/6-ChIPseq/3-DataAnalysis/4-dunnartPeaks/1-FullDataset/")
geneCounts <- read.table("geneCounts.txt", header=TRUE)

ggplot(geneCounts, aes(element, freq, fill = element)) +     
  geom_boxplot() + theme(legend.position="none") + theme_bw() + xlab("") + ylab("Number of peaks per gene") + theme(legend.position="none") + scale_fill_manual(values = c("#199480", "#99cfc6") )

# Top genes with high number of peaks (enhancers and promoters)
sortGeneCounts <- geneCounts[order(-geneCounts$freq),]


# Number of consensus peaks for H3K4me3 and H3K27ac
tbl <- with(fullPeaks, table(sample, sample))

ggplot(as.data.frame(tbl), aes(factor(sample), Freq, fill = sample)) +     
  geom_col(position = 'dodge') + theme(legend.position="none")  + theme_bw() + xlab("") + 
  ylab("Number of peaks") + theme(axis.ticks.x=element_blank(), legend.position="none") + 
  scale_y_continuous(expand = c(0, 0)) + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1))

# Number of consensus peaks for combined peaks
tbl <- with(enh_prom, table(sample, sample))

ggplot(as.data.frame(tbl), aes(factor(sample), Freq, fill = sample)) +     
  geom_col(position = 'stack') + theme(legend.position="none") + theme_bw() + 
  xlab("") + ylab("Number of peaks") + theme(axis.ticks.x=element_blank(), 
                                             axis.line.x=element_blank(), 
                                             legend.position="none") + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1)) + 
  scale_y_continuous(expand = c(0, 0))

# Peak lengths for H3K4me3 and H3K27ac
fullPeaks$length <- (fullPeaks$V3 - fullPeaks$V2)
fullPeaks$lengthkb <- fullPeaks$length / 1000

ggplot(fullPeaks, aes(sample, log10(lengthkb), fill = sample)) +     
  geom_boxplot() + theme(legend.position="none") + theme_bw() + xlab("") + 
  ylab("Log 10 peak length (kb)") + theme(axis.ticks.x=element_blank(), legend.position="none") + scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1))

# Peak lengths for enhancers and promoters
enh_prom$length <- (enh_prom$V3 - enh_prom$V2)
enh_prom$lengthkb <- enh_prom$length / 1000

ggplot(enh_prom, aes(sample, log10(lengthkb), fill = sample)) +     
  geom_boxplot() + theme(legend.position="none") + 
  theme_bw() + xlab("") + ylab("Log 10 peak length (kb)") + 
  theme(legend.position="none") + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1)) + 
  scale_y_continuous(expand = c(0, 0))

# Peak intensity (fold-change) for enhancer/promoters and full peaks
ggplot(fullPeaks, aes(sample, V7, fill = sample)) +     
  geom_boxplot() + theme(legend.position="none") + theme_bw() + xlab("") + ylab("Peak intensity (fold-change)") + theme(legend.position="none")  + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                                 "#DDDDDD", "#DDDDDD",
                                 "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                                 "#FFAABB", "#FFAABB", 
                                 "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1))


ggplot(enh_prom, aes(sample, V7, fill = sample)) +     
  geom_boxplot() + theme(legend.position="none") + theme_bw() + xlab("") + ylab("Peak intensity (fold-change)") + theme(legend.position="none") + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#FFAABB", "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB", 
                               "#FFAABB", "#FFAABB")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1))

  ### Filter top 20,000 peaks in dunnart and see peak intensities
  H3K4me3top <- data.table(dH3K4me3[order(-dH3K4me3$V7), ][1:20000,])
  H3K27actop <- data.table(dH3K27ac[order(-dH3K27ac$V7), ][1:30000,])
  fullPeaks <- rbind(H3K4me3top, H3K27actop, mH3K27E10, mH3K27E11, mH3K27E12, mH3K27E13, mH3K27E14, mH3K27E15, mH3K4E10, mH3K4E11, mH3K4E12, mH3K4E13, mH3K4E14, mH3K4E15)
  
  enhTop <- data.table(denhancer[order(-denhancer$V7), ][1:20000,])
  promTop <- data.table(dpromoter[order(-dpromoter$V7), ][1:20000,])
  enh_prom <- rbind(enhTop, promTop, enhancer10, enhancer11, enhancer12, enhancer13, enhancer14, enhancer15, promoter10, promoter11, promoter12, promoter13, promoter14, promoter15 )
  
  
###################################################################################################
#################################### BINNING PEAKS ################################################
###################################################################################################

## Convert peak lengths to a data table
data_table <- data.table(enh_prom[ which(enh_prom$species=='mouse'
                         & enh_prom$sample=='promoter E10.5'), ])


## Bin peaks into different widths
data_table = data_table[
  ,binned_column:= ifelse(length <= 1001, '0-1000',
                          ifelse(length > 1001 & length <=2001,'1001-2000',
                                 ifelse(length > 2001 & length <=3001,'201-3000',
                                        ifelse(length > 3001 & length <=4001,'3001-4000',
                                               ifelse(length > 4001 & length <=5001,'4001-5000',
                                                      ifelse(length > 5001 & length <=6001,'5001-6000',
                                                             ifelse(length > 6001 & length <=7001,'6001-7000',
                                                                    ifelse(length > 7001 & length <=8001,'7001-8000',
                                                                           ifelse(length > 8001 & length <=9001,'8001-9000',
                                                                                  ifelse(length > 9001 & length <=10001,'901-10000',
                                                                                         ifelse(length > 10001 & length <=11001,'10001-11000',
                                                                                                ifelse(length > 11001 & length <=12001,'11001-12000',
                                                                                                       ifelse(length > 12001 & length <=13001,'12001-13000',
                                                                                                              ifelse(length > 13001 & length <=14001,'13001-14000',
                                                                                                                     ifelse(length > 14001 & length <=15001,'14001-15000',
                                                                                                                            ifelse(length > 15001 & length <=16001,'15001-16000',
                                                                                                                                   ifelse(length > 16000, '>16000', 'NA'
                                 )))))))))))))))))
]


level_order <-c("0-1000", "1001-2000", 
                  "2001-3000", "3001-4000", 
                "4001-5000", "5001-6000", 
                "6001-7000", "7001-8000", 
                "8001-9000", "9001-10000", 
                "10001-11000", "11001-12000",
                "12001-13000", "13001-14000",
                "14001-15000", "15001-16000",
                ">16000")

tbl <- with(data_table, table(binned_column, binned_column))

ggplot(as.data.frame(tbl), aes(factor(binned_column, levels=level_order), Freq, fill = binned_column)) +
  geom_col(position = 'dodge') + theme(legend.position="none")  + theme_bw() + xlab("") + ggtitle("mouse E10.5 promoters")+
  ylab("Number of peaks") + theme(axis.ticks.x=element_blank(), legend.position="none")+
  scale_y_continuous(expand = c(0, 0)) + 
  scale_fill_manual(values = c("#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD",
                               "#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", 
                               "#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD", "#DDDDDD")) + 
  theme(axis.text.x = element_text(angle = 60, hjust = 1))
