## Input: peak metrics from peak_metrics.R
## Output: PCA plots and tables

library(mixOmics)
library(dplyr)

## PCA on peak metrics
PCAnalysisALL <- function(file, plot10, plot20, plot30, plot40){
  file = read.table(file, header=TRUE,  row.names = 1)

  #df =merge(promoter, enhancer,by='row.names',all=TRUE)
  #rownames(df) = df[,1]
  #df = df[-1,-1]

  intensitySum <- file %>% dplyr::select(contains("intensity.Sum"))
  colnames(intensitySum) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  df <- t(intensitySum)
  df[is.na(df)] <- 0
  df.pca <- spca(df, scale=TRUE)
  pdf(plot10)    
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  intensityMean = file %>% dplyr::select(contains("intensityMean"))
  colnames(intensityMean) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  df <- t(intensityMean)
  df[is.na(df)] <- 0
  df.pca <- spca(df, scale=TRUE)
  pdf(plot20)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  intensity = file %>% dplyr::select(contains("intensity.Median")) 
  colnames(intensity) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  df <- t(intensity)
  df[is.na(df)] <- 0
  df.pca <- spca(df, scale=TRUE)
  #write.table((selectVar(df.pca, comp = 1)$value), loadingPC1, sep="\t", quote=F, row.names=T)
  #write.table((selectVar(df.pca, comp = 2)$value), loadingPC2, sep="\t", quote=F, row.names=T)
  pdf(plot30)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  peak.counts =  file %>% dplyr::select(contains("peak.fraction"))
  colnames(peak.counts) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  df <- t(peak.counts)
  df <- df[, colSums(df != 0) > 0]
  df.pca <- pca(df)
  pdf(plot40)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()
}

setwd('/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation')
PCAnalysisALL(file = "promoterPeaksPerGene_clustered.txt", plot10 = "promoterintensitySum_clustered.pdf", plot20 ="promoterintensityMean_clustered.pdf", 
plot30="promoterintensity.Median_clustered.pdf", plot40="promoterPeak.fraction_clustered.pdf")

PCAnalysisALL(file = "enhancerPeaksPerGene_subsample.txt", plot10 = "enhancerIntensitySum_subsample.pdf", plot20 ="enhancerintensityMean_subsample.pdf", 
plot30="enhancerintensity.Median_subsample.pdf", plot40="enhancerPeak.fraction_subsample.pdf")

PCAnalysismm10<- function(file, plot10, plot20, plot30, plot40){
  file = read.table(file, header=TRUE,  row.names = 1)

  #df =merge(promoter, enhancer,by='row.names',all=TRUE)
  #rownames(df) = df[,1]
  #df = df[-1,-1]

  intensitySum <- file %>% dplyr::select(contains("intensity.Sum"))
  colnames(intensitySum) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensitySum <- intensitySum %>% dplyr::select("mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensitySum <- intensitySum[apply(intensitySum[,-1], 1, function(x) !all(x==0)),]
  df <- t(intensitySum)
  df[is.na(df)] <- 0
  df.pca <- pca(df, scale=TRUE)
  pdf(plot10)    
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  intensityMean = file %>% dplyr::select(contains("intensityMean"))
  colnames(intensityMean) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensityMean <- intensityMean %>% dplyr::select("mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensityMean <- intensityMean[apply(intensityMean[,-1], 1, function(x) !all(x==0)),]

  df <- t(intensityMean)
  df[is.na(df)] <- 0
  df.pca <- spca(df, scale=TRUE)
  pdf(plot20)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  intensity = file %>% dplyr::select(contains("intensity.Median")) 
  colnames(intensity) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensity <- intensity %>% dplyr::select("mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  intensity<- intensity[apply(intensity[,-1], 1, function(x) !all(x==0)),]

  df <- t(intensity)
  df[is.na(df)] <- 0
  df.pca <- spca(df, scale=TRUE)
  #write.table((selectVar(df.pca, comp = 1)$value), loadingPC1, sep="\t", quote=F, row.names=T)
  #write.table((selectVar(df.pca, comp = 2)$value), loadingPC2, sep="\t", quote=F, row.names=T)
  pdf(plot30)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()

  peak.counts =  file %>% dplyr::select(contains("peak.fraction"))
  colnames(peak.counts) <- c("dunnart", "mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  peak.counts <- peak.counts %>% dplyr::select("mouse_E10.5", "mouse_E11.5", "mouse_E12.5", "mouse_E13.5", "mouse_E14.5", "mouse_E15.5")
  peak.counts <- peak.counts[apply(peak.counts[,-1], 1, function(x) !all(x==0)),]

  df <- t(peak.counts)
  df <- df[, colSums(df != 0) > 0]
  df.pca <- pca(df)
  pdf(plot40)
  plotIndiv(df.pca, scale=T)
  plot(df.pca)
  plotLoadings(df.pca)
  plotLoadings(df.pca, comp=2)
  dev.off()
}

setwd('/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation')
PCAnalysismm10(file = "promoterPeaksPerGene_clustered.txt", plot10 = "promoterintensitySum_clustered.mm10.pdf", plot20 ="promoterintensityMean_clustered.mm10.pdf", 
plot30="promoterintensity.Median_clustered.mm10.pdf", plot40="promoterPeak.fraction_clustered.mm10.pdf")

PCAnalysismm10(file = "enhancerPeaksPerGene_subsample.txt", plot10 = "enhancerIntensitySum_subsample.pdf", plot20 ="enhancerintensityMean_subsample.pdf", 
plot30="enhancerintensity.Median_subsample.pdf", plot40="enhancerPeak.fraction_subsample.pdf")